Pbkdf2Error

Enum Pbkdf2Error 

#[non_exhaustive]
pub enum Pbkdf2Error { InvalidIterations, OutputTooLong, }
Available on (crate features hmac or hkdf or kmac or ed25519 or x25519 or phc-strings or argon2 or scrypt) and crate feature pbkdf2 only.
Invalid PBKDF2 parameters.

Returned when the iteration count is zero or the derived key length exceeds the RFC 2898 maximum of (2^32 − 1) × hLen.

Examples

use rscrypto::{Pbkdf2Sha256, auth::Pbkdf2Error};

let err = Pbkdf2Sha256::derive_key(b"pw", b"salt", 0, &mut [0u8; 32]);
assert_eq!(err, Err(Pbkdf2Error::InvalidIterations));

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidIterations

The iteration count must be at least 1. NIST/OWASP policy minima are documented on Pbkdf2Sha256::MIN_RECOMMENDED_ITERATIONS and Pbkdf2Sha512::MIN_RECOMMENDED_ITERATIONS.



OutputTooLong

The requested output length exceeds (2^32 − 1) × hLen.